@@ -1,5 +1,5 @@
 /* Extended cpio header from POSIX.1.
-   Copyright (C) 1992, 2006, 2007 Free Software Foundation, Inc.
+   Copyright (C) 1992, 2006, 2007, 2010 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,44 +18,44 @@
 
 #ifndef _CPIOHDR_H
 
-#define _CPIOHDR_H 1
+# define _CPIOHDR_H 1
 
-#include <cpio.h>
+# include <cpio.h>
 
-#ifdef HAVE_ATTRIB_PACKED
-#define ATTRIB_PACKED __attribute__((packed))
-#endif
+# ifdef HAVE_ATTRIB_PACKED
+#  define ATTRIB_PACKED __attribute__((packed))
+# endif
 
-#ifdef HAVE_PRAGMA_PACK
-#pragma pack(1)
-#endif
+# ifdef HAVE_PRAGMA_PACK
+#  pragma pack(1)
+# endif
 
-#ifdef HAVE_PRAGMA_PACK_HPPA
-#pragma pack 1
-#endif
+# ifdef HAVE_PRAGMA_PACK_HPPA
+#  pragma pack 1
+# endif
 
 struct old_cpio_header
 {
   unsigned short c_magic;
-  short c_dev;
+  unsigned short c_dev;
   unsigned short c_ino;
   unsigned short c_mode;
   unsigned short c_uid;
   unsigned short c_gid;
   unsigned short c_nlink;
-  short c_rdev;
+  unsigned short c_rdev;
   unsigned short c_mtimes[2];
   unsigned short c_namesize;
   unsigned short c_filesizes[2];
 } ATTRIB_PACKED;
 
-#ifdef HAVE_PRAGMA_PACK
-#pragma pack(1)
-#endif
+# ifdef HAVE_PRAGMA_PACK
+#  pragma pack(1)
+# endif
 
-#ifdef HAVE_PRAGMA_PACK_HPPA
-#pragma pack 1
-#endif
+# ifdef HAVE_PRAGMA_PACK_HPPA
+#  pragma pack 1
+# endif
 struct old_ascii_header
 {
   char c_magic[6];
@@ -81,13 +81,13 @@ struct old_ascii_header
 /* All the fields in the header are ISO 646 (approximately ASCII) strings
    of hexadecimal numbers, left padded, not NUL terminated: */
 
-#ifdef HAVE_PRAGMA_PACK
-#pragma pack(1)
-#endif
+# ifdef HAVE_PRAGMA_PACK
+#  pragma pack(1)
+# endif
 
-#ifdef HAVE_PRAGMA_PACK_HPPA
-#pragma pack 1
-#endif
+# ifdef HAVE_PRAGMA_PACK_HPPA
+#  pragma pack 1
+# endif
 struct new_ascii_header
 {
   char c_magic[6];     /* "070701" for "new" portable format
